@@ -5,7 +5,7 @@ from aquests.protocols.http import http_util
 import base64
 from functools import wraps
 from skitai.exceptions import HTTPError
-
+from urllib.parse import urlparse
 class AuthorizedUser:
     def __init__ (self, user, realm, info = None):
         self.name = user
@@ -136,9 +136,7 @@ class Auth:
         origin = request.get_header ('Origin')
         if not origin:
             return True
-        if not allowed_origins:
-            allowed_origins = ["%s://%s" % (request.get_scheme (), request.get_header ("host", ""))]
-        elif "*" in allowed_origins:
+        if not allowed_origins or "*" in allowed_origins:
             return True
         if origin in allowed_origins:
             return True
@@ -270,6 +268,7 @@ class Auth:
         if not __donotusethisvariable__:
             __donotusethisvariable__ = set ()
         else:
+            assert isinstance (__donotusethisvariable__, (list, tuple, set))
             __donotusethisvariable__ = set (__donotusethisvariable__)
 
         def decorator(f):
